Method: Sc2::Paths.exec_working_dir
- Defined in:
- lib/sc2ai/paths.rb
.exec_working_dir ⇒ String?
Working directory if required by platform Some platforms the correct working directory for launch to find linked libraries
151 152 153 154 155 156 |
# File 'lib/sc2ai/paths.rb', line 151 def exec_working_dir cwd = WORKING_DIR[platform] return nil if cwd.nil? Pathname(install_dir).join(cwd).to_s end |